summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCernat Cosmin (uidv0912) <uidv0912@iav5723u.cw01.contiwan.com>2015-10-09 16:43:23 +0300
committerCernat Cosmin (uidv0912) <uidv0912@iav5723u.cw01.contiwan.com>2015-10-09 16:44:21 +0300
commit8a032131d703624262fd4ff1316716b4190b06d1 (patch)
treeeb15506db42ece143eb37fe92c433f2d82a91c9b
parent1b168f21d12c8ba36655546c400cfd961241092b (diff)
downloadpersistence-administrator-8a032131d703624262fd4ff1316716b4190b06d1.tar.gz
PAS Vers. 1.0.6 - Fixed bug 295: further calls of persadmin_tool install return with exit code: -1310719
Change-Id: I2b7d4b406381ee11881436a64d5ef86d60fd302a Signed-off-by: Cernat Cosmin <cosmin.cernat@continental-corporation.com>
-rw-r--r--Administrator/src/ssw_pers_admin_files_helper.c25
-rw-r--r--ChangeLog5
-rw-r--r--configure.ac2
3 files changed, 26 insertions, 6 deletions
diff --git a/ChangeLog b/ChangeLog
index f8bb9f4..3157a4a 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,6 +1,11 @@
persistence-administrator ChangeLog
===================================
+Version 1.0.6 9.10.2015
+------------------------
+
+1. Fixed Bug 295 - further calls of persadmin_tool install return with exit code: -1310719
+
Version 1.0.4 16.09.2014
------------------------
diff --git a/configure.ac b/configure.ac
index a8a9ad3..4386371 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ dnl **************************************************************************
dnl *** First, define all of the version numbers up front ***
dnl *** In particular, this allows the version macro to be used in AC_INIT ***
dnl **************************************************************************
-m4_define([PERS_PACKAGE_VERSION_S],[1.0.5])
+m4_define([PERS_PACKAGE_VERSION_S],[1.0.6])
m4_define([PERS_ADMINACCESSLIB_VERSION_N],[1000000])
dnl ***************************
diff --git a/Administrator/src/ssw_pers_admin_files_helper.c b/Administrator/src/ssw_pers_admin_files_helper.c
index b4e2a1f..83e95db 100644
--- a/Administrator/src/ssw_pers_admin_files_helper.c
+++ b/Administrator/src/ssw_pers_admin_files_helper.c
@@ -11,11 +11,12 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/.
*
* Date Author Reason
-* 2014.02.03 uidl9757 CSP_WZ#8463: Added persadmin_get_file_size()
-* 2013.05.30 uidl9757 CSP_WZ#12188: Rework persadmin_get_folder_size()
-* 2013.02.07 uidu0250 CSP_WZ#2220: Added persadmin_check_for_same_file_content to check for identical file content
-* 2012.11.16 uidv2833 CSP_WZ#1280: persadmin_delete_folder and persadmin_delete_file return the number of bytes deleted
-* 2012.11.15 uidl9757 CSP_WZ#1280: Some extensions:
+* 2015.10.09 Cosmin Cernat Bug 295: In persadmin_create_symbolic_link() if the symlink already exists, delete it before creating it.
+* 2014.02.03 Ionut Ieremie CSP_WZ#8463: Added persadmin_get_file_size()
+* 2013.05.30 Ionut Ieremie CSP_WZ#12188: Rework persadmin_get_folder_size()
+* 2013.02.07 Petrica Manoila CSP_WZ#2220: Added persadmin_check_for_same_file_content to check for identical file content
+* 2012.11.16 Alin Liteanu CSP_WZ#1280: persadmin_delete_folder and persadmin_delete_file return the number of bytes deleted
+* 2012.11.15 Ionut Ieremie CSP_WZ#1280: Some extensions:
- persadmin_copy_folder and persadmin_copy_file return the number of bytes copied
- added persadmin_check_if_file_exist and persadmin_check_if_file_exist
- fixed some bugs
@@ -456,6 +457,20 @@ sint_t persadmin_create_symbolic_link(pstr_t pathLink, pstr_t pathTarget)
if(bEverythingOK)
{
+ /* if the symlink already exists, delete it */
+ if(0 <= persadmin_check_if_file_exists(pathLink, false))
+ {
+ if(0 > persadmin_delete_file(pathLink))
+ {
+ bEverythingOK = false ;
+ (void)snprintf(g_msg, sizeof(g_msg), ": persadmin_delete_file(%s) failed", pathLink) ;
+ DLT_LOG(persAdminSvcDLTCtx, DLT_LOG_ERROR, DLT_STRING(LT_HDR), DLT_STRING(__FUNCTION__), DLT_STRING(g_msg));
+ }
+ }
+ }
+
+ if(bEverythingOK)
+ {
if(0 != symlink(pathTarget, pathLink))
{
bEverythingOK = false ;